@@ -1,4 +1,3 @@
-use futures::io::BufReader;
 use nom::{
     branch::alt,
     bytes::streaming::{tag, take_until},
@@ -6,6 +5,7 @@ use nom::{
     combinator::map_res,
     IResult,
 };
+use nom_bufreader::async_bufreader::BufReader;
 use nom_bufreader::{AsyncParse, Error};
 use std::str::from_utf8;
 use tokio_util::compat::TokioAsyncReadCompatExt;
